Crate virtual_node

Crate virtual_node 

The virtual_node module exposes the VirtualNode struct and methods that power our virtual dom.

Re-exports

pub use self::event::EventAttribFn;

Modules

event
test_utils
A collection of functions that are useful for unit testing your html! views.

Structs

IterableNodes
Used by the html! macro for all braced child nodes so that we can use any type that implements Into
KeyNotSetError
An error when attempting to perform an action that requires the SpecialAttributes::key to be set.
SpecialAttributes
A specially supported attributes.
VirtualElement
VirtualText
Represents a text node

Enums

AttributeValue
The value associated with an element’s attribute.
VirtualNode
When building your views you’ll typically use the html! macro to generate VirtualNode’s.

Traits

View
A trait with common functionality for rendering front-end views.

Type Aliases

VirtualNodeWebSys
A VirtualNode whose RealDom is a web_sys::Window.