Module event

Module event 

Structs

ElementEventsId
Uniquely identifies an element so that we can store it’s events in VirtualEvents.
EventAttribFn
A handler for an event, such the closure in onmyevent = || {}.
EventName
The name of the event with the on prefix.
Events
We need a custom implementation of fmt::Debug since JsValue doesn’t implement debug.
MouseEvent
A mouse event.
VirtualEventElement
A virtual event element node.
VirtualEventNode
A tree where each entry holds the events for the corresponding entry in a crate::VirtualNode tree.
VirtualEvents
When we create a DOM node, we store all of it’s closures and all of it’s children’s closures in VirtualEvents.

Enums

EventHandler
Event handlers such as the closure in onclick = |mouse_event| {}.

Traits

EventCallback
A callback that runs when an event is triggered.

Functions

insert_non_delegated_event
Attaches an event handler directly onto a DOM element.